@@ -3,6 +3,8 @@ import click
 from hyperscale.ozone.iam import GitHubOIDCProvider
 from hyperscale.ozone.rvm import RoleVendingMachine
 from hyperscale.ozone.rvm import WorkflowRole
+from hyperscale.ozone.s3 import CentralLogArchiveBuckets
+from hyperscale.ozone.s3 import CentralS3AccessLogsReplicationRole
 from hyperscale.ozone.s3 import LocalAccessLogsBucket
 
 
@@ -14,6 +16,10 @@ def main():
 
 
 TEMPLATES = {
+    "central-log-archive-buckets": (
+        CentralLogArchiveBuckets(),
+        "Central log archive buckets",
+    ),
     "role-vending-machine": (RoleVendingMachine(), "A Role Vending Machine"),
     "rvm-workflow-role": (
         WorkflowRole(),
@@ -25,6 +31,10 @@ TEMPLATES = {
         "account",
     ),
     "github-oidc-provider": (GitHubOIDCProvider(), "An IAM OIDC provider for GitHub"),
+    "central-s3-access-logs-replication-role": (
+        CentralS3AccessLogsReplicationRole(),
+        "A role for replicating s3 objects to the central s3 access logs bucket",
+    ),
 }
 
 
